Slice a CTDF into putative clusters using temporal continuity and spatial clustering
Source:R/1_slice.R
slice_ctdf.RdIdentifies spatially heterogeneous regions (via HDBSCAN on point coordinates) and, for those regions, recursively subdivides the track into temporally continuous movement segments. Subdivision continues until a region is spatially homogeneous (no evidence for multiple clusters) .
Details
This function updates a ctdf in-place.
Internally, candidate regions are queued. Regions that show evidence for multiple clusters are split by movement segmentation; otherwise they are retained as a single putative cluster.