Skip to contents

Identifies spatially heterogeneous regions (via HDBSCAN on point coordinates) and, for those regions, recursively subdivides the track into temporally continuous movement segments. Subdivision continues until a region is spatially homogeneous (no evidence for multiple clusters) .

Usage

slice_ctdf(ctdf, nmin = 5, deltaT)

Arguments

ctdf

A CTDF object.

nmin

Integer; smallest size of a putative cluster.

deltaT

Numeric; maximum allowable time gap (in days) between segment endpoints for intersections to consider them continuous.

Value

Invisibly returns ctdf, with .putative_cluster updated in-place.

Details

This function updates a ctdf in-place.

Internally, candidate regions are queued. Regions that show evidence for multiple clusters are split by movement segmentation; otherwise they are retained as a single putative cluster.

See also

Examples

data(mini_ruff)
ctdf = as_ctdf(mini_ruff, s_srs = 4326, t_srs = "+proj=eqearth")
ctdf = slice_ctdf(ctdf)

data(pesa56511)
ctdf = as_ctdf(pesa56511, time = "locationDate", s_srs = 4326, t_srs = "+proj=eqearth")
ctdf = slice_ctdf(ctdf)
#>  ⠙ 23 segments processed [2s]
#>  ⠹ 32 segments processed [2.2s]
#>  ⠸ 36 segments processed [2.4s]
#>  ⠼ 44 segments processed [2.6s]
#>  ⠼ 46 segments processed [2.7s]