Removes leading and trailing "tail" portions of each .putative_cluster based on self-crossings
of the within-cluster track. The intent is to keep only the locally revisited core of a cluster
and drop commuting legs at the both beginning and end.
Removes leading and trailing "tail" portions of each .putative_cluster based on self-crossings
of the within-cluster track. The intent is to keep only the locally revisited core of a cluster
and drop commuting legs at the both beginning and end.